==> license-checker-1.4.1-sources.jar: com/vaadin/pro/licensechecker/ProKeyValidator.java <==
package com.vaadin.pro.licensechecker;

import java.io.IOException;
import java.io.InputStream;
import java.net.ConnectException;
import java.net.SocketTimeoutException;
import java.net.URL;
import java.net.URLConnection;
import java.net.UnknownHostException;

import org.slf4j.Logger;

import elemental.json.Json;
import elemental.json.JsonObject;

public class ProKeyValidator {

    private static final String UNABLE_TO_VALIDATE_SUBSCRIPTION = "Unable to validate subscription."
            + " Please go to https://vaadin.com/pro/validate-license to check that your subscription is active."
            + " For troubleshooting steps, see https://vaadin.com/licensing-faq-and-troubleshooting.";
    private static final String LICENSE_VALIDATION_URL = "https://tools.vaadin.com/vaadin-license-server/licenses/pro";
    private static final String[] PROPERTIES = new String[] { "java.vendor",
            "java.version", "os.arch", "os.name", "os.version" };

    private static Logger getLogger() {
        return LicenseChecker.getLogger();
    }

    public static boolean validate(Product product, ProKey proKey, String machineId) {
        if (proKey == null) {
            getLogger().debug("No pro key found to validate");
            throw new RuntimeException(UNABLE_TO_VALIDATE_SUBSCRIPTION);
        }
        getLogger().debug("Validating pro key for " + product);
        if (History.isRecentlyValidated(product)) {
            // check only every 24h
            getLogger().debug(
                    "Skipping check as product license was recently validated.");
            return true;
        }
        try {
            JsonObject response = queryServer(product, proKey, machineId);
            if (validateServerResponse(product, response)) {
                History.setLastCheckTimeNow(product);
                History.setLastSubscription(product,
                        response.getString("subscription"));
                return true;
            } else {
                // Key does not have access to the given product
                // Subscription might have ended or some other problem
                return false;
            }
        } catch (UnknownHostException | ConnectException | SocketTimeoutException e) {
            return false;
        } catch (Exception e) {
            getLogger().error(UNABLE_TO_VALIDATE_SUBSCRIPTION, e);
            return false;
        }
    }

    /**
     * @return subscription (Trial, Pro, ...) if success, null otherwise
     */
    public static String getSubscription(Product product, ProKey proKey) {
        if (proKey == null) {
            getLogger().debug("No pro key found to get subscription");
            return null;
        }
        return History.getLastSubscription(product);
    }

    private static boolean validateServerResponse(Product product,
            JsonObject response) {
        getLogger().info("Validating license for " + product.getName() + " " +
                product.getVersion());
        String result = response.getString("result");
        String message = response.getString("message");
        if (message != null && !message.isEmpty()) {
            getLogger().info(message);
        }
        return "ok".equals(result);
    }

    private static JsonObject queryServer(Product product, ProKey proKey, String machineId) throws IOException {
        URL url = new URL(LICENSE_VALIDATION_URL);
        URLConnection http = url.openConnection();
        http.setRequestProperty("check-source", "java");
        http.setRequestProperty("machine-id", machineId);
        http.setRequestProperty("product-name", product.getName());
        http.setRequestProperty("product-version", product.getVersion());
        for (String property : PROPERTIES) {
            String value = System.getProperty(property);
            if (value != null) {
                http.setRequestProperty("prop-" + property.replace(".", "-"),
                        value);
            }
        }

        http.setRequestProperty("product-version", product.getVersion());
        http.setRequestProperty("Cookie", "proKey=" + proKey.getProKey());
        http.setConnectTimeout(5000);
        http.setReadTimeout(5000);
        http.connect();

        try (InputStream in = http.getInputStream()) {
            String response = Util.toString(in);
            return Json.parse(response);
        }
    }

}

==> license-checker-1.5.1-sources.jar: com/vaadin/pro/licensechecker/ProKeyValidator.java <==
package com.vaadin.pro.licensechecker;

import java.io.IOException;
import java.io.InputStream;
import java.net.ConnectException;
import java.net.SocketTimeoutException;
import java.net.URL;
import java.net.URLConnection;
import java.net.UnknownHostException;

import org.slf4j.Logger;

import elemental.json.Json;
import elemental.json.JsonObject;

public class ProKeyValidator {

    private static final String UNABLE_TO_VALIDATE_SUBSCRIPTION = "Unable to validate subscription."
            + " Please go to https://vaadin.com/pro/validate-license to check that your subscription is active."
            + " For troubleshooting steps, see https://vaadin.com/licensing-faq-and-troubleshooting.";
    private static final String LICENSE_VALIDATION_URL = "https://tools.vaadin.com/vaadin-license-server/licenses/pro";
    private static final String[] PROPERTIES = new String[] { "java.vendor",
            "java.version", "os.arch", "os.name", "os.version" };

    private static Logger getLogger() {
        return LicenseChecker.getLogger();
    }

    public static enum Result {
        OK,
        NO_ACCESS,
        CANNOT_REACH_SERVER
    }

    Result validate(Product product, ProKey proKey, String machineId) {
        getLogger().debug("Online validation using proKey for " + product);
        if (proKey == null) {
            getLogger().debug("No pro key found");
            return Result.NO_ACCESS;
        }
        if (History.isRecentlyValidated(product)) {
            // check only every 24h
            getLogger().debug(
                    "Skipping check as product license was recently validated.");
            return Result.OK;
        }
        try {
            JsonObject response = queryServer(product, proKey, machineId);
            if (validateServerResponse(product, response)) {
                History.setLastCheckTimeNow(product);
                History.setLastSubscription(product,
                        response.getString("subscription"));
                getLogger().debug("Pro key OK");
                return Result.OK;
            } else {
                // Key does not have access to the given product
                // Subscription might have ended or some other problem
                getLogger().debug("Pro key does not have access");
                return Result.NO_ACCESS;
            }
        } catch (UnknownHostException | ConnectException | SocketTimeoutException e) {
            getLogger().debug("Pro key unable to connect to server");
            return Result.CANNOT_REACH_SERVER;
        } catch (Exception e) {
            getLogger().error(UNABLE_TO_VALIDATE_SUBSCRIPTION, e);
            getLogger().debug("Pro key checking failed with exception", e);
            return Result.NO_ACCESS;
        }
    }

    /**
     * @return subscription (Trial, Pro, ...) if success, null otherwise
     */
    static String getSubscription(Product product, ProKey proKey) {
        if (proKey == null) {
            getLogger().debug("No pro key found to get subscription");
            return null;
        }
        return History.getLastSubscription(product);
    }

    private static boolean validateServerResponse(Product product,
            JsonObject response) {
        getLogger().info("Validating license for " + product.getName() + " " +
                product.getVersion());
        String result = response.getString("result");
        String message = response.getString("message");
        if (message != null && !message.isEmpty()) {
            getLogger().info(message);
        }
        return "ok".equals(result);
    }

    private static JsonObject queryServer(Product product, ProKey proKey, String machineId) throws IOException {
        URL url = new URL(LICENSE_VALIDATION_URL);
        URLConnection http = url.openConnection();
        http.setRequestProperty("check-source", "java");
        http.setRequestProperty("machine-id", machineId);
        http.setRequestProperty("product-name", product.getName());
        http.setRequestProperty("product-version", product.getVersion());
        for (String property : PROPERTIES) {
            String value = System.getProperty(property);
            if (value != null) {
                http.setRequestProperty("prop-" + property.replace(".", "-"),
                        value);
            }
        }

        http.setRequestProperty("product-version", product.getVersion());
        http.setRequestProperty("Cookie", "proKey=" + proKey.getProKey());
        http.setConnectTimeout(5000);
        http.setReadTimeout(5000);
        http.connect();

        try (InputStream in = http.getInputStream()) {
            String response = Util.toString(in);
            return Json.parse(response);
        }
    }

}
